@@ -8,7 +8,7 @@ from urllib.parse import urlparse
 
 from agno.document.base import Document
 from agno.document.reader.base import Reader
-from agno.utils.log import logger
+from agno.utils.log import log_info, logger
 
 
 class CSVReader(Reader):
@@ -19,10 +19,10 @@ class CSVReader(Reader):
             if isinstance(file, Path):
                 if not file.exists():
                     raise FileNotFoundError(f"Could not find file: {file}")
-                logger.info(f"Reading: {file}")
+                log_info(f"Reading: {file}")
                 file_content = file.open(newline="", mode="r", encoding="utf-8")
             else:
-                logger.info(f"Reading uploaded file: {file.name}")
+                log_info(f"Reading uploaded file: {file.name}")
                 file.seek(0)
                 file_content = io.StringIO(file.read().decode("utf-8"))  # type: ignore
 
@@ -54,6 +54,19 @@ class CSVReader(Reader):
 class CSVUrlReader(Reader):
     """Reader for CSV files"""
 
+    _csv_reader: CSVReader
+
+    @property
+    def csv_reader(self) -> CSVReader:
+        if self._csv_reader is None:
+            self._csv_reader = CSVReader(
+                chunk=self.chunk,
+                chunk_size=self.chunk_size,
+                chunking_strategy=self.chunking_strategy,
+                separators=self.separators,
+            )
+        return self._csv_reader
+
     def read(self, url: str) -> List[Document]:
         if not url:
             raise ValueError("No URL provided")
@@ -63,7 +76,7 @@ class CSVUrlReader(Reader):
         except ImportError:
             raise ImportError("`httpx` not installed")
 
-        logger.info(f"Reading: {url}")
+        log_info(f"Reading: {url}")
         # Retry the request up to 3 times with exponential backoff
         for attempt in range(3):
             try:
@@ -89,7 +102,7 @@ class CSVUrlReader(Reader):
         file_obj = io.BytesIO(response.content)
         file_obj.name = filename
 
-        documents = CSVReader().read(file=file_obj)
+        documents = self.csv_reader.read(file=file_obj)
 
         file_obj.close()
 
