@@ -31,16 +31,16 @@ class OpenAIEmbedder(Embedder):
         if self.openai_client:
             return self.openai_client
 
-        _client_params: Dict[str, Any] = {}
-        if self.api_key:
-            _client_params["api_key"] = self.api_key
-        if self.organization:
-            _client_params["organization"] = self.organization
-        if self.base_url:
-            _client_params["base_url"] = self.base_url
+        _client_params: Dict[str, Any] = {
+            "api_key": self.api_key,
+            "organization": self.organization,
+            "base_url": self.base_url,
+        }
+        _client_params = {k: v for k, v in _client_params.items() if v is not None}
         if self.client_params:
             _client_params.update(self.client_params)
-        return OpenAIClient(**_client_params)
+        self.openai_client = OpenAIClient(**_client_params)
+        return self.openai_client
 
     def response(self, text: str) -> CreateEmbeddingResponse:
         _request_params: Dict[str, Any] = {
