@@ -1,6 +1,8 @@
 from pathlib import Path
 from typing import Iterator, List, Union
 
+from pydantic import Field
+
 from agno.document import Document
 from agno.document.reader.csv_reader import CSVReader
 from agno.knowledge.agent import AgentKnowledge
@@ -8,6 +10,7 @@ from agno.knowledge.agent import AgentKnowledge
 
 class CSVKnowledgeBase(AgentKnowledge):
     path: Union[str, Path]
+    exclude_files: List[str] = Field(default_factory=list)
     reader: CSVReader = CSVReader()
 
     @property
@@ -23,6 +26,10 @@ class CSVKnowledgeBase(AgentKnowledge):
 
         if _csv_path.exists() and _csv_path.is_dir():
             for _csv in _csv_path.glob("**/*.csv"):
+                if _csv.name in self.exclude_files:
+                    continue
                 yield self.reader.read(file=_csv)
         elif _csv_path.exists() and _csv_path.is_file() and _csv_path.suffix == ".csv":
+            if _csv_path.name in self.exclude_files:
+                return
             yield self.reader.read(file=_csv_path)
