@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-from enum import Enum
 from typing import Any, Dict, List, Optional, Tuple
 
 from pydantic import BaseModel, ConfigDict
@@ -8,12 +7,12 @@ from pydantic import BaseModel, ConfigDict
 from agno.memory.classifier import MemoryClassifier
 from agno.memory.db import MemoryDb
 from agno.memory.manager import MemoryManager
-from agno.memory.memory import Memory
+from agno.memory.memory import Memory, MemoryRetrieval
 from agno.memory.summarizer import MemorySummarizer
 from agno.memory.summary import SessionSummary
 from agno.models.message import Message
 from agno.run.response import RunResponse
-from agno.utils.log import logger
+from agno.utils.log import log_debug, log_info, logger
 
 
 class AgentRun(BaseModel):
@@ -32,12 +31,6 @@ class AgentRun(BaseModel):
         return {k: v for k, v in response.items() if v is not None}
 
 
-class MemoryRetrieval(str, Enum):
-    last_n = "last_n"
-    first_n = "first_n"
-    semantic = "semantic"
-
-
 class AgentMemory(BaseModel):
     # Runs between the user and agent
     runs: List[AgentRun] = []
@@ -78,8 +71,6 @@ class AgentMemory(BaseModel):
         _memory_dict = self.model_dump(
             exclude_none=True,
             include={
-                "runs",
-                "messages",
                 "update_system_message_on_change",
                 "create_session_summary",
                 "update_session_summary_after_run",
@@ -106,7 +97,7 @@ class AgentMemory(BaseModel):
     def add_run(self, agent_run: AgentRun) -> None:
         """Adds an AgentRun to the runs list."""
         self.runs.append(agent_run)
-        logger.debug("Added AgentRun to AgentMemory")
+        log_debug("Added AgentRun to AgentMemory")
 
     def add_system_message(self, message: Message, system_message_role: str = "system") -> None:
         """Add the system messages to the messages list"""
@@ -125,21 +116,16 @@ class AgentMemory(BaseModel):
                     self.messages[system_message_index].content != message.content
                     and self.update_system_message_on_change
                 ):
-                    logger.info("Updating system message in memory with new content")
+                    log_info("Updating system message in memory with new content")
                     self.messages[system_message_index] = message
             else:
                 # Add the system message to the messages list
                 self.messages.insert(0, message)
 
-    def add_message(self, message: Message) -> None:
-        """Add a Message to the messages list."""
-        self.messages.append(message)
-        logger.debug("Added Message to AgentMemory")
-
     def add_messages(self, messages: List[Message]) -> None:
         """Add a list of messages to the messages list."""
         self.messages.extend(messages)
-        logger.debug(f"Added {len(messages)} Messages to AgentMemory")
+        log_debug(f"Added {len(messages)} Messages to AgentMemory")
 
     def get_messages(self) -> List[Dict[str, Any]]:
         """Returns the messages list as a list of dictionaries."""
@@ -177,7 +163,7 @@ class AgentMemory(BaseModel):
 
                 messages_from_history.append(message)
 
-        logger.debug(f"Getting messages from previous runs: {len(messages_from_history)}")
+        log_debug(f"Getting messages from previous runs: {len(messages_from_history)}")
         return messages_from_history
 
     def get_message_pairs(
@@ -196,12 +182,16 @@ class AgentMemory(BaseModel):
 
                 # Start from the beginning to look for the user message
                 for message in run.response.messages:
+                    if hasattr(message, "from_history") and message.from_history:
+                        continue
                     if message.role == user_role:
                         user_messages_from_run = message
                         break
 
                 # Start from the end to look for the assistant response
                 for message in run.response.messages[::-1]:
+                    if hasattr(message, "from_history") and message.from_history:
+                        continue
                     if message.role in assistant_role:
                         assistant_messages_from_run = message
                         break
@@ -238,7 +228,7 @@ class AgentMemory(BaseModel):
             else:
                 raise NotImplementedError("Semantic retrieval not yet supported.")
         except Exception as e:
-            logger.debug(f"Error reading memory: {e}")
+            log_debug(f"Error reading memory: {e}")
             return
 
         # Clear the existing memories
@@ -296,10 +286,10 @@ class AgentMemory(BaseModel):
 
         # Check if this user message should be added to long term memory
         should_update_memory = force or self.should_update_memory(input=input)
-        logger.debug(f"Update memory: {should_update_memory}")
+        log_debug(f"Update memory: {should_update_memory}")
 
         if not should_update_memory:
-            logger.debug("Memory update not required")
+            log_debug("Memory update not required")
             return "Memory update not required"
 
         if self.manager is None:
@@ -329,10 +319,10 @@ class AgentMemory(BaseModel):
 
         # Check if this user message should be added to long term memory
         should_update_memory = force or await self.ashould_update_memory(input=input)
-        logger.debug(f"Async update memory: {should_update_memory}")
+        log_debug(f"Async update memory: {should_update_memory}")
 
         if not should_update_memory:
-            logger.debug("Memory update not required")
+            log_debug("Memory update not required")
             return "Memory update not required"
 
         if self.manager is None:
