@@ -7,9 +7,9 @@ from typing import Any, Dict, List, Optional, Tuple, Union
 from agno.exceptions import ModelProviderError, ModelRateLimitError
 from agno.media import File, Image
 from agno.models.base import Model
-from agno.models.message import Message
+from agno.models.message import Citations, DocumentCitation, Message
 from agno.models.response import ModelResponse
-from agno.utils.log import logger
+from agno.utils.log import log_error, log_warning
 
 try:
     from anthropic import Anthropic as AnthropicClient
@@ -40,10 +40,29 @@ def _format_image_for_message(image: Image) -> Optional[Dict[str, Any]]:
     """
     Add an image to a message by converting it to base64 encoded format.
     """
-    import base64
-    import imghdr
+    using_filetype = False
 
-    type_mapping = {"jpeg": "image/jpeg", "png": "image/png", "gif": "image/gif", "webp": "image/webp"}
+    import base64
+
+    # 'imghdr' was deprecated in Python 3.11: https://docs.python.org/3/library/imghdr.html
+    # 'filetype' used as a fallback
+    try:
+        import imghdr
+    except (ModuleNotFoundError, ImportError):
+        try:
+            import filetype
+
+            using_filetype = True
+        except (ModuleNotFoundError, ImportError):
+            raise ImportError("`filetype` not installed. Please install using `pip install filetype`")
+
+    type_mapping = {
+        "jpeg": "image/jpeg",
+        "jpg": "image/jpeg",
+        "png": "image/png",
+        "gif": "image/gif",
+        "webp": "image/webp",
+    }
 
     try:
         # Case 1: Image is a URL
@@ -59,7 +78,7 @@ def _format_image_for_message(image: Image) -> Optional[Dict[str, Any]]:
                 with open(image.filepath, "rb") as f:
                     content_bytes = f.read()
             else:
-                logger.error(f"Image file not found: {image}")
+                log_error(f"Image file not found: {image}")
                 return None
 
         # Case 3: Image is a bytes object
@@ -67,17 +86,26 @@ def _format_image_for_message(image: Image) -> Optional[Dict[str, Any]]:
             content_bytes = image.content
 
         else:
-            logger.error(f"Unsupported image type: {type(image)}")
+            log_error(f"Unsupported image type: {type(image)}")
             return None
 
-        img_type = imghdr.what(None, h=content_bytes)  # type: ignore
+        if using_filetype:
+            kind = filetype.guess(content_bytes)
+            if not kind:
+                log_error("Unable to determine image type")
+                return None
+
+            img_type = kind.extension
+        else:
+            img_type = imghdr.what(None, h=content_bytes)  # type: ignore
+
         if not img_type:
-            logger.error("Unable to determine image type")
+            log_error("Unable to determine image type")
             return None
 
         media_type = type_mapping.get(img_type)
         if not media_type:
-            logger.error(f"Unsupported image type: {img_type}")
+            log_error(f"Unsupported image type: {img_type}")
             return None
 
         return {
@@ -90,7 +118,7 @@ def _format_image_for_message(image: Image) -> Optional[Dict[str, Any]]:
         }
 
     except Exception as e:
-        logger.error(f"Error processing image: {e}")
+        log_error(f"Error processing image: {e}")
         return None
 
 
@@ -98,6 +126,12 @@ def _format_file_for_message(file: File) -> Optional[Dict[str, Any]]:
     """
     Add a document url or base64 encoded content to a message.
     """
+
+    mime_mapping = {
+        "application/pdf": "base64",
+        "text/plain": "text",
+    }
+
     # Case 1: Document is a URL
     if file.url is not None:
         return {
@@ -106,6 +140,7 @@ def _format_file_for_message(file: File) -> Optional[Dict[str, Any]]:
                 "type": "url",
                 "url": file.url,
             },
+            "citations": {"enabled": True},
         }
     # Case 2: Document is a local file path
     elif file.filepath is not None:
@@ -115,29 +150,35 @@ def _format_file_for_message(file: File) -> Optional[Dict[str, Any]]:
         path = Path(file.filepath) if isinstance(file.filepath, str) else file.filepath
         if path.exists() and path.is_file():
             file_data = base64.standard_b64encode(path.read_bytes()).decode("utf-8")
+
+            # Determine media type
             media_type = file.mime_type
             if media_type is None:
                 import mimetypes
 
-                media_type = mimetypes.guess_type(file.filepath)[0]
-                if media_type != "application/pdf":
-                    logger.error(f"Unsupported file type: {media_type}")
+                media_type = mimetypes.guess_type(file.filepath)[0] or "application/pdf"
+
+            # Map media type to type, default to "base64" if no mapping exists
+            type = mime_mapping.get(media_type, "base64")
+
             return {
                 "type": "document",
                 "source": {
-                    "type": "base64",
+                    "type": type,
                     "media_type": media_type,
                     "data": file_data,
                 },
+                "citations": {"enabled": True},
             }
         else:
-            logger.error(f"Document file not found: {file}")
+            log_error(f"Document file not found: {file}")
             return None
     # Case 3: Document is base64 encoded content
     elif file.content is not None:
         return {
             "type": "document",
             "source": {"type": "base64", "media_type": "application/pdf", "data": file.content},
+            "citations": {"enabled": True},
         }
     return None
 
@@ -251,7 +292,7 @@ class Claude(Model):
 
         self.api_key = self.api_key or getenv("ANTHROPIC_API_KEY")
         if not self.api_key:
-            logger.error("ANTHROPIC_API_KEY not set. Please set the ANTHROPIC_API_KEY environment variable.")
+            log_error("ANTHROPIC_API_KEY not set. Please set the ANTHROPIC_API_KEY environment variable.")
 
         # Add API key to client parameters
         client_params["api_key"] = self.api_key
@@ -391,18 +432,18 @@ class Claude(Model):
                 **request_kwargs,
             )
         except APIConnectionError as e:
-            logger.error(f"Connection error while calling Claude API: {str(e)}")
+            log_error(f"Connection error while calling Claude API: {str(e)}")
             raise ModelProviderError(message=e.message, model_name=self.name, model_id=self.id) from e
         except RateLimitError as e:
-            logger.warning(f"Rate limit exceeded: {str(e)}")
+            log_warning(f"Rate limit exceeded: {str(e)}")
             raise ModelRateLimitError(message=e.message, model_name=self.name, model_id=self.id) from e
         except APIStatusError as e:
-            logger.error(f"Claude API error (status {e.status_code}): {str(e)}")
+            log_error(f"Claude API error (status {e.status_code}): {str(e)}")
             raise ModelProviderError(
                 message=e.message, status_code=e.status_code, model_name=self.name, model_id=self.id
             ) from e
         except Exception as e:
-            logger.error(f"Unexpected error calling Claude API: {str(e)}")
+            log_error(f"Unexpected error calling Claude API: {str(e)}")
             raise ModelProviderError(message=str(e), model_name=self.name, model_id=self.id) from e
 
     def invoke_stream(self, messages: List[Message]) -> Any:
@@ -429,18 +470,18 @@ class Claude(Model):
                 .__enter__()
             )
         except APIConnectionError as e:
-            logger.error(f"Connection error while calling Claude API: {str(e)}")
+            log_error(f"Connection error while calling Claude API: {str(e)}")
             raise ModelProviderError(message=e.message, model_name=self.name, model_id=self.id) from e
         except RateLimitError as e:
-            logger.warning(f"Rate limit exceeded: {str(e)}")
+            log_warning(f"Rate limit exceeded: {str(e)}")
             raise ModelRateLimitError(message=e.message, model_name=self.name, model_id=self.id) from e
         except APIStatusError as e:
-            logger.error(f"Claude API error (status {e.status_code}): {str(e)}")
+            log_error(f"Claude API error (status {e.status_code}): {str(e)}")
             raise ModelProviderError(
                 message=e.message, status_code=e.status_code, model_name=self.name, model_id=self.id
             ) from e
         except Exception as e:
-            logger.error(f"Unexpected error calling Claude API: {str(e)}")
+            log_error(f"Unexpected error calling Claude API: {str(e)}")
             raise ModelProviderError(message=str(e), model_name=self.name, model_id=self.id) from e
 
     async def ainvoke(self, messages: List[Message]) -> AnthropicMessage:
@@ -468,18 +509,18 @@ class Claude(Model):
                 **request_kwargs,
             )
         except APIConnectionError as e:
-            logger.error(f"Connection error while calling Claude API: {str(e)}")
+            log_error(f"Connection error while calling Claude API: {str(e)}")
             raise ModelProviderError(message=e.message, model_name=self.name, model_id=self.id) from e
         except RateLimitError as e:
-            logger.warning(f"Rate limit exceeded: {str(e)}")
+            log_warning(f"Rate limit exceeded: {str(e)}")
             raise ModelRateLimitError(message=e.message, model_name=self.name, model_id=self.id) from e
         except APIStatusError as e:
-            logger.error(f"Claude API error (status {e.status_code}): {str(e)}")
+            log_error(f"Claude API error (status {e.status_code}): {str(e)}")
             raise ModelProviderError(
                 message=e.message, status_code=e.status_code, model_name=self.name, model_id=self.id
             ) from e
         except Exception as e:
-            logger.error(f"Unexpected error calling Claude API: {str(e)}")
+            log_error(f"Unexpected error calling Claude API: {str(e)}")
             raise ModelProviderError(message=str(e), model_name=self.name, model_id=self.id) from e
 
     async def ainvoke_stream(self, messages: List[Message]) -> AsyncIterator[Any]:
@@ -503,18 +544,18 @@ class Claude(Model):
                 async for chunk in stream:
                     yield chunk
         except APIConnectionError as e:
-            logger.error(f"Connection error while calling Claude API: {str(e)}")
+            log_error(f"Connection error while calling Claude API: {str(e)}")
             raise ModelProviderError(message=e.message, model_name=self.name, model_id=self.id) from e
         except RateLimitError as e:
-            logger.warning(f"Rate limit exceeded: {str(e)}")
+            log_warning(f"Rate limit exceeded: {str(e)}")
             raise ModelRateLimitError(message=e.message, model_name=self.name, model_id=self.id) from e
         except APIStatusError as e:
-            logger.error(f"Claude API error (status {e.status_code}): {str(e)}")
+            log_error(f"Claude API error (status {e.status_code}): {str(e)}")
             raise ModelProviderError(
                 message=e.message, status_code=e.status_code, model_name=self.name, model_id=self.id
             ) from e
         except Exception as e:
-            logger.error(f"Unexpected error calling Claude API: {str(e)}")
+            log_error(f"Unexpected error calling Claude API: {str(e)}")
             raise ModelProviderError(message=str(e), model_name=self.name, model_id=self.id) from e
 
     # Overwrite the default from the base model
@@ -531,11 +572,11 @@ class Claude(Model):
         """
         if len(function_call_results) > 0:
             fc_responses: List = []
-            for _fc_message_index, _fc_message in enumerate(function_call_results):
+            for _fc_message in function_call_results:
                 fc_responses.append(
                     {
                         "type": "tool_result",
-                        "tool_use_id": tool_ids[_fc_message_index],
+                        "tool_use_id": _fc_message.tool_call_id,
                         "content": _fc_message.content,
                     }
                 )
@@ -566,7 +607,17 @@ class Claude(Model):
         if response.content:
             for block in response.content:
                 if block.type == "text":
-                    model_response.content = block.text
+                    if model_response.content is None:
+                        model_response.content = block.text
+                    else:
+                        model_response.content += block.text
+
+                    if block.citations:
+                        model_response.citations = Citations(raw=block.citations, documents=[])
+                        for citation in block.citations:
+                            model_response.citations.documents.append(  # type: ignore
+                                DocumentCitation(document_title=citation.document_title, cited_text=citation.cited_text)
+                            )
                 elif block.type == "thinking":
                     model_response.thinking = block.thinking
                     model_response.provider_data = {
@@ -624,6 +675,12 @@ class Claude(Model):
             # Handle text content
             if response.delta.type == "text_delta":
                 model_response.content = response.delta.text
+            elif response.delta.type == "citation_delta":
+                citation = response.delta.citation
+                model_response.citations = Citations(raw=citation)
+                model_response.citations.documents.append(  # type: ignore
+                    DocumentCitation(document_title=citation.document_title, cited_text=citation.cited_text)
+                )
             # Handle thinking content
             elif response.delta.type == "thinking_delta":
                 model_response.thinking = response.delta.thinking
