@@ -4,13 +4,13 @@ from os import getenv
 from typing import Any, Dict, Iterator, List, Optional, Union
 
 import httpx
-from anthropic import BaseModel
+from pydantic import BaseModel
 
 from agno.exceptions import ModelProviderError
 from agno.models.base import Model
 from agno.models.message import Message
 from agno.models.response import ModelResponse
-from agno.utils.log import logger
+from agno.utils.log import log_error, log_warning
 from agno.utils.openai import images_to_message
 
 try:
@@ -59,10 +59,10 @@ def _format_message(message: Message) -> Dict[str, Any]:
             message_dict["content"].extend(images_to_message(images=message.images))
 
     if message.audio is not None:
-        logger.warning("Audio input is currently unsupported.")
+        log_warning("Audio input is currently unsupported.")
 
     if message.videos is not None:
-        logger.warning("Video input is currently unsupported.")
+        log_warning("Video input is currently unsupported.")
 
     return message_dict
 
@@ -107,9 +107,6 @@ class AzureAIFoundry(Model):
     client: Optional[ChatCompletionsClient] = None
     async_client: Optional[AsyncChatCompletionsClient] = None
 
-    # Internal parameters
-    structured_outputs: bool = False
-
     def _get_request_kwargs(self) -> Dict[str, Any]:
         """Get the parameters for creating an Azure AI request."""
         base_params = {
@@ -224,7 +221,7 @@ class AzureAIFoundry(Model):
                 messages=[_format_message(m) for m in messages], **self._get_request_kwargs()
             )
         except HttpResponseError as e:
-            logger.error(f"Azure AI API error: {e}")
+            log_error(f"Azure AI API error: {e}")
             raise ModelProviderError(
                 message=e.reason or "Azure AI API error",
                 status_code=e.status_code or 502,
@@ -232,7 +229,7 @@ class AzureAIFoundry(Model):
                 model_id=self.id,
             ) from e
         except Exception as e:
-            logger.error(f"Error from Azure AI API: {e}")
+            log_error(f"Error from Azure AI API: {e}")
             raise ModelProviderError(message=str(e), model_name=self.name, model_id=self.id) from e
 
     async def ainvoke(self, messages: List[Message]) -> Any:
@@ -253,7 +250,7 @@ class AzureAIFoundry(Model):
                     **self._get_request_kwargs(),
                 )
         except HttpResponseError as e:
-            logger.error(f"Azure AI API error: {e}")
+            log_error(f"Azure AI API error: {e}")
             raise ModelProviderError(
                 message=e.reason or "Azure AI API error",
                 status_code=e.status_code or 502,
@@ -261,7 +258,7 @@ class AzureAIFoundry(Model):
                 model_id=self.id,
             ) from e
         except Exception as e:
-            logger.error(f"Error from Azure AI API: {e}")
+            log_error(f"Error from Azure AI API: {e}")
             raise ModelProviderError(message=str(e), model_name=self.name, model_id=self.id) from e
 
     def invoke_stream(self, messages: List[Message]) -> Iterator[Any]:
@@ -279,7 +276,7 @@ class AzureAIFoundry(Model):
                 messages=[_format_message(m) for m in messages], stream=True, **self._get_request_kwargs()
             )
         except HttpResponseError as e:
-            logger.error(f"Azure AI API error: {e}")
+            log_error(f"Azure AI API error: {e}")
             raise ModelProviderError(
                 message=e.reason or "Azure AI API error",
                 status_code=e.status_code or 502,
@@ -287,7 +284,7 @@ class AzureAIFoundry(Model):
                 model_id=self.id,
             ) from e
         except Exception as e:
-            logger.error(f"Error from Azure AI API: {e}")
+            log_error(f"Error from Azure AI API: {e}")
             raise ModelProviderError(message=str(e), model_name=self.name, model_id=self.id) from e
 
     async def ainvoke_stream(self, messages: List[Message]) -> AsyncIterator[Any]:
@@ -311,7 +308,7 @@ class AzureAIFoundry(Model):
                     yield chunk
 
         except HttpResponseError as e:
-            logger.error(f"Azure AI API error: {e}")
+            log_error(f"Azure AI API error: {e}")
             raise ModelProviderError(
                 message=e.reason or "Azure AI API error",
                 status_code=e.status_code or 502,
@@ -319,7 +316,7 @@ class AzureAIFoundry(Model):
                 model_id=self.id,
             ) from e
         except Exception as e:
-            logger.error(f"Error from Azure AI API: {e}")
+            log_error(f"Error from Azure AI API: {e}")
             raise ModelProviderError(message=str(e), model_name=self.name, model_id=self.id) from e
 
     def parse_provider_response(self, response: ChatCompletions) -> ModelResponse:
@@ -369,7 +366,7 @@ class AzureAIFoundry(Model):
                 }
 
         except Exception as e:
-            logger.error(f"Error parsing Azure AI response: {e}")
+            log_error(f"Error parsing Azure AI response: {e}")
             raise ModelProviderError(message=str(e), model_name=self.name, model_id=self.id) from e
 
         return model_response
@@ -439,7 +436,7 @@ class AzureAIFoundry(Model):
                 }
 
         except Exception as e:
-            logger.error(f"Error parsing Azure AI response delta: {e}")
+            log_error(f"Error parsing Azure AI response delta: {e}")
             raise ModelProviderError(message=str(e), model_name=self.name, model_id=self.id) from e
 
         return model_response
