@@ -2,16 +2,16 @@ import asyncio
 import collections.abc
 from abc import ABC, abstractmethod
 from dataclasses import dataclass, field
-from types import GeneratorType
+from types import AsyncGeneratorType, GeneratorType
 from typing import Any, AsyncGenerator, AsyncIterator, Dict, Iterator, List, Literal, Optional, Tuple, Union
 from uuid import uuid4
 
 from agno.exceptions import AgentRunException
 from agno.media import AudioResponse
-from agno.models.message import Message, MessageMetrics
+from agno.models.message import Citations, Message, MessageMetrics
 from agno.models.response import ModelResponse, ModelResponseEvent
 from agno.tools.function import Function, FunctionCall
-from agno.utils.log import logger
+from agno.utils.log import log_debug, log_error, log_warning
 from agno.utils.timer import Timer
 from agno.utils.tools import get_function_call_for_tool_call
 
@@ -22,6 +22,7 @@ class MessageData:
     response_content: Any = ""
     response_thinking: Any = ""
     response_redacted_thinking: Any = ""
+    response_citations: Optional[Citations] = None
     response_tool_calls: List[Dict[str, Any]] = field(default_factory=list)
     response_audio: Optional[AudioResponse] = None
 
@@ -49,7 +50,9 @@ class Model(ABC):
     # Whether to generate structured outputs from this Model.
     structured_outputs: bool = False
     # True if the Model supports structured outputs natively (e.g. OpenAI)
-    supports_structured_outputs: bool = False
+    supports_native_structured_outputs: bool = False
+    # True if the Model requires a json_schema for structured outputs (e.g. LMStudio)
+    supports_json_schema_outputs: bool = False
 
     # Controls which (if any) function is called by the model.
     # "none" means the model will not call a function and instead generates a message.
@@ -160,8 +163,10 @@ class Model(ABC):
         Returns:
             ModelResponse: The model's response
         """
-        logger.debug(f"---------- {self.get_provider()} Response Start ----------")
-        logger.debug(f"---------- Model: {self.id} ----------")
+
+        log_debug(f"{self.get_provider()} Response Start", center=True, symbol="-")
+        log_debug(f"Model: {self.id}", center=True, symbol="-")
+
         self._log_messages(messages)
         model_response = ModelResponse()
 
@@ -191,14 +196,19 @@ class Model(ABC):
                         and function_call_response.tool_calls is not None
                     ):
                         model_response.tool_calls.extend(function_call_response.tool_calls)
+                    elif function_call_response.event not in [
+                        ModelResponseEvent.tool_call_started.value,
+                        ModelResponseEvent.tool_call_completed.value,
+                    ]:
+                        if function_call_response.content:
+                            model_response.content += function_call_response.content  # type: ignore
 
                 # Format and add results to messages
                 self.format_function_call_results(
                     messages=messages, function_call_results=function_call_results, **model_response.extra or {}
                 )
-
-                logger.debug(f"---------- {self.get_provider()} Response ----------")
-                self._log_messages(messages)
+                for function_call_result in function_call_results:
+                    function_call_result.log(metrics=True)
 
                 # Check if we should stop after tool calls
                 if any(m.stop_after_tool_call for m in function_call_results):
@@ -210,7 +220,7 @@ class Model(ABC):
             # No tool calls or finished processing them
             break
 
-        logger.debug(f"---------- {self.get_provider()} Response End ----------")
+        log_debug(f"{self.get_provider()} Response End", center=True, symbol="-")
         return model_response
 
     async def aresponse(self, messages: List[Message]) -> ModelResponse:
@@ -223,8 +233,9 @@ class Model(ABC):
         Returns:
             ModelResponse: The model's response
         """
-        logger.debug(f"---------- {self.get_provider()} Async Response Start ----------")
-        logger.debug(f"---------- Model: {self.id} ----------")
+
+        log_debug(f"{self.get_provider()} Async Response Start", center=True, symbol="-")
+        log_debug(f"Model: {self.id}", center=True, symbol="-")
         self._log_messages(messages)
         model_response = ModelResponse()
 
@@ -254,26 +265,31 @@ class Model(ABC):
                         and function_call_response.tool_calls is not None
                     ):
                         model_response.tool_calls.extend(function_call_response.tool_calls)
+                    elif function_call_response.event not in [
+                        ModelResponseEvent.tool_call_started.value,
+                        ModelResponseEvent.tool_call_completed.value,
+                    ]:
+                        if function_call_response.content:
+                            model_response.content += function_call_response.content
 
                 # Format and add results to messages
                 self.format_function_call_results(
                     messages=messages, function_call_results=function_call_results, **model_response.extra or {}
                 )
+                for function_call_result in function_call_results:
+                    function_call_result.log(metrics=True)
 
                 # Check if we should stop after tool calls
                 if any(m.stop_after_tool_call for m in function_call_results):
                     break
 
-                logger.debug(f"---------- {self.get_provider()} Async Response ----------")
-                self._log_messages(messages)
-
                 # Continue loop to get next response
                 continue
 
             # No tool calls or finished processing them
             break
 
-        logger.debug(f"---------- {self.get_provider()} Async Response End ----------")
+        log_debug(f"{self.get_provider()} Async Response End", center=True, symbol="-")
         return model_response
 
     def _process_model_response(
@@ -309,7 +325,7 @@ class Model(ABC):
         messages.append(assistant_message)
 
         # Log response and metrics
-        assistant_message.log()
+        assistant_message.log(metrics=True)
 
         # Update model response with assistant message content and audio
         if assistant_message.content is not None:
@@ -321,6 +337,8 @@ class Model(ABC):
             model_response.thinking = assistant_message.thinking
         if assistant_message.redacted_thinking is not None:
             model_response.redacted_thinking = assistant_message.redacted_thinking
+        if assistant_message.citations is not None:
+            model_response.citations = assistant_message.citations
         if assistant_message.audio_output is not None:
             model_response.audio = assistant_message.audio_output
         if provider_response.extra is not None:
@@ -375,6 +393,8 @@ class Model(ABC):
             model_response.thinking = assistant_message.thinking
         if assistant_message.redacted_thinking is not None:
             model_response.redacted_thinking = assistant_message.redacted_thinking
+        if assistant_message.citations is not None:
+            model_response.citations = assistant_message.citations
         if assistant_message.audio_output is not None:
             model_response.audio = assistant_message.audio_output
         if provider_response.extra is not None:
@@ -431,6 +451,10 @@ class Model(ABC):
         if provider_response.provider_data is not None:
             assistant_message.provider_data = provider_response.provider_data
 
+        # Add citations to assistant message
+        if provider_response.citations is not None:
+            assistant_message.citations = provider_response.citations
+
         # Add usage metrics if provided
         if provider_response.response_usage is not None:
             self._add_usage_metrics_to_assistant_message(
@@ -461,8 +485,9 @@ class Model(ABC):
         Returns:
             Iterator[ModelResponse]: Iterator of model responses
         """
-        logger.debug(f"---------- {self.get_provider()} Response Stream Start ----------")
-        logger.debug(f"---------- Model: {self.id} ----------")
+
+        log_debug(f"{self.get_provider()} Response Stream Start", center=True, symbol="-")
+        log_debug(f"Model: {self.id}", center=True, symbol="-")
         self._log_messages(messages)
 
         while True:
@@ -486,6 +511,8 @@ class Model(ABC):
                 assistant_message.redacted_thinking = stream_data.response_redacted_thinking
             if stream_data.response_provider_data:
                 assistant_message.provider_data = stream_data.response_provider_data
+            if stream_data.response_citations:
+                assistant_message.citations = stream_data.response_citations
             if stream_data.response_audio:
                 assistant_message.audio_output = stream_data.response_audio
             if stream_data.response_tool_calls and len(stream_data.response_tool_calls) > 0:
@@ -493,7 +520,7 @@ class Model(ABC):
 
             # Add assistant message to messages
             messages.append(assistant_message)
-            assistant_message.log()
+            assistant_message.log(metrics=True)
 
             # Handle tool calls if present
             if assistant_message.tool_calls is not None:
@@ -501,10 +528,6 @@ class Model(ABC):
                 function_calls_to_run: List[FunctionCall] = self.get_function_calls_to_run(assistant_message, messages)
                 function_call_results: List[Message] = []
 
-                # Show tool calls if enabled
-                if self.show_tool_calls:
-                    yield from self._show_stream_tool_calls(function_calls_to_run=function_calls_to_run)
-
                 # Execute function calls
                 for function_call_response in self.run_function_calls(
                     function_calls=function_calls_to_run, function_call_results=function_call_results
@@ -519,8 +542,8 @@ class Model(ABC):
                 else:
                     self.format_function_call_results(messages=messages, function_call_results=function_call_results)
 
-                logger.debug(f"---------- {self.get_provider()} Response Stream ----------")
-                self._log_messages(messages)
+                for function_call_result in function_call_results:
+                    function_call_result.log(metrics=True)
 
                 # Check if we should stop after tool calls
                 if any(m.stop_after_tool_call for m in function_call_results):
@@ -532,7 +555,7 @@ class Model(ABC):
             # No tool calls or finished processing them
             break
 
-        logger.debug(f"---------- {self.get_provider()} Response Stream End ----------")
+        log_debug(f"{self.get_provider()} Response Stream End", center=True, symbol="-")
 
     async def aprocess_response_stream(
         self, messages: List[Message], assistant_message: Message, stream_data: MessageData
@@ -557,8 +580,9 @@ class Model(ABC):
         Returns:
             AsyncIterator[ModelResponse]: Async iterator of model responses
         """
-        logger.debug(f"---------- {self.get_provider()} Async Response Stream Start ----------")
-        logger.debug(f"---------- Model: {self.id} ----------")
+
+        log_debug(f"{self.get_provider()} Async Response Stream Start", center=True, symbol="-")
+        log_debug(f"Model: {self.id}", center=True, symbol="-")
         self._log_messages(messages)
 
         while True:
@@ -598,11 +622,6 @@ class Model(ABC):
                 function_calls_to_run: List[FunctionCall] = self.get_function_calls_to_run(assistant_message, messages)
                 function_call_results: List[Message] = []
 
-                # Show tool calls if enabled
-                if self.show_tool_calls:
-                    for model_response in self._show_stream_tool_calls(function_calls_to_run):
-                        yield model_response
-
                 # Execute function calls
                 async for function_call_response in self.arun_function_calls(
                     function_calls=function_calls_to_run, function_call_results=function_call_results
@@ -617,8 +636,8 @@ class Model(ABC):
                 else:
                     self.format_function_call_results(messages=messages, function_call_results=function_call_results)
 
-                logger.debug(f"---------- {self.get_provider()} Async Response Stream ----------")
-                self._log_messages(messages)
+                for function_call_result in function_call_results:
+                    function_call_result.log(metrics=True)
 
                 # Check if we should stop after tool calls
                 if any(m.stop_after_tool_call for m in function_call_results):
@@ -630,7 +649,7 @@ class Model(ABC):
             # No tool calls or finished processing them
             break
 
-        logger.debug(f"---------- {self.get_provider()} Async Response Stream End ----------")
+        log_debug(f"{self.get_provider()} Async Response Stream End", center=True, symbol="-")
 
     def _populate_stream_data_and_assistant_message(
         self, stream_data: MessageData, assistant_message: Message, model_response: ModelResponse
@@ -659,6 +678,10 @@ class Model(ABC):
             stream_data.response_redacted_thinking += model_response.redacted_thinking
             should_yield = True
 
+        if model_response.citations is not None:
+            stream_data.response_citations = model_response.citations
+            should_yield = True
+
         if model_response.provider_data:
             if stream_data.response_provider_data is None:
                 stream_data.response_provider_data = {}
@@ -765,7 +788,7 @@ class Model(ABC):
                     try:
                         additional_messages.append(Message(**m))
                     except Exception as e:
-                        logger.warning(f"Failed to convert dict to Message: {e}")
+                        log_warning(f"Failed to convert dict to Message: {e}")
 
         if a_exc.stop_execution:
             for m in additional_messages:
@@ -824,7 +847,7 @@ class Model(ABC):
                 # Set function call success to False if an exception occurred
                 function_call_success = False
             except Exception as e:
-                logger.error(f"Error executing function {fc.function.name}: {e}")
+                log_error(f"Error executing function {fc.function.name}: {e}")
                 function_call_success = False
                 raise e
 
@@ -869,22 +892,26 @@ class Model(ABC):
 
     async def _arun_function_call(
         self, function_call: FunctionCall
-    ) -> tuple[Union[bool, AgentRunException], Timer, FunctionCall]:
+    ) -> Tuple[Union[bool, AgentRunException], Timer, FunctionCall]:
         """Run a single function call and return its success status, timer, and the FunctionCall object."""
-        from inspect import iscoroutinefunction
+        from inspect import isasyncgenfunction, iscoroutine, iscoroutinefunction
 
         function_call_timer = Timer()
         function_call_timer.start()
         success: Union[bool, AgentRunException] = False
         try:
-            if iscoroutinefunction(function_call.function.entrypoint):
+            if (
+                iscoroutinefunction(function_call.function.entrypoint)
+                or isasyncgenfunction(function_call.function.entrypoint)
+                or iscoroutine(function_call.function.entrypoint)
+            ):
                 success = await function_call.aexecute()
             else:
                 success = await asyncio.to_thread(function_call.execute)
         except AgentRunException as e:
             success = e  # Pass the exception through to be handled by caller
         except Exception as e:
-            logger.error(f"Error executing function {function_call.function.name}: {e}")
+            log_error(f"Error executing function {function_call.function.name}: {e}")
             success = False
             raise e
 
@@ -920,7 +947,7 @@ class Model(ABC):
         for result in results:
             # If result is an exception, skip processing it
             if isinstance(result, BaseException):
-                logger.error(f"Error during function call: {result}")
+                log_error(f"Error during function call: {result}")
                 raise result
 
             # Unpack result
@@ -941,6 +968,11 @@ class Model(ABC):
                     function_call_output += item
                     if fc.function.show_result:
                         yield ModelResponse(content=item)
+            elif isinstance(fc.result, (AsyncGeneratorType, collections.abc.AsyncIterator)):
+                async for item in fc.result:
+                    function_call_output += item
+                    if fc.function.show_result:
+                        yield ModelResponse(content=item)
             else:
                 function_call_output = fc.result
                 if fc.function.show_result:
@@ -969,35 +1001,6 @@ class Model(ABC):
         if additional_messages:
             function_call_results.extend(additional_messages)
 
-    def _show_tool_calls(self, function_calls_to_run: List[FunctionCall], model_response: ModelResponse):
-        """
-        Show tool calls in the model response.
-        """
-        if len(function_calls_to_run) == 1:
-            if model_response.content and len(model_response.content) > 0 and model_response.content[-1] != "\n":
-                model_response.content += "\n\n"
-            else:
-                model_response.content = ""
-            model_response.content += f" - Running: {function_calls_to_run[0].get_call_str()}\n\n"
-        elif len(function_calls_to_run) > 1:
-            if model_response.content and len(model_response.content) > 0 and model_response.content[-1] != "\n":
-                model_response.content += "\n\n"
-            else:
-                model_response.content = ""
-            model_response.content += "Running:"
-            for _f in function_calls_to_run:
-                model_response.content += f"\n - {_f.get_call_str()}"
-            model_response.content += "\n\n"
-
-    def _show_stream_tool_calls(self, function_calls_to_run: List[FunctionCall]) -> Iterator[ModelResponse]:
-        if len(function_calls_to_run) == 1:
-            yield ModelResponse(content=f" - Running: {function_calls_to_run[0].get_call_str()}\n\n")
-        else:
-            yield ModelResponse(content="\nRunning:")
-            for _f in function_calls_to_run:
-                yield ModelResponse(content=f"\n - {_f.get_call_str()}")
-            yield ModelResponse(content="\n\n")
-
     def _prepare_function_calls(
         self,
         assistant_message: Message,
@@ -1020,8 +1023,6 @@ class Model(ABC):
             model_response.tool_calls = []
 
         function_calls_to_run: List[FunctionCall] = self.get_function_calls_to_run(assistant_message, messages)
-        if self.show_tool_calls and function_calls_to_run:
-            self._show_tool_calls(function_calls_to_run, model_response)
         return function_calls_to_run
 
     def format_function_call_results(
@@ -1102,7 +1103,8 @@ class Model(ABC):
         Log messages for debugging.
         """
         for m in messages:
-            m.log()
+            # Don't log metrics for input messages
+            m.log(metrics=False)
 
     def get_system_message_for_model(self) -> Optional[str]:
         return self.system_prompt
