@@ -7,7 +7,7 @@ from pydantic import BaseModel
 from agno.models.base import Model
 from agno.models.message import Message
 from agno.models.response import ModelResponse
-from agno.utils.log import logger
+from agno.utils.log import log_debug, log_warning
 
 try:
     from ollama import AsyncClient as AsyncOllamaClient
@@ -41,7 +41,7 @@ class Ollama(Model):
     name: str = "Ollama"
     provider: str = "Ollama"
 
-    supports_structured_outputs: bool = True
+    supports_native_structured_outputs: bool = True
 
     # Request parameters
     format: Optional[Any] = None
@@ -118,7 +118,7 @@ class Ollama(Model):
             for tool in request_params["tools"]:  # type: ignore
                 if "parameters" in tool["function"] and "properties" in tool["function"]["parameters"]:  # type: ignore
                     for _, obj in tool["function"]["parameters"].get("properties", {}).items():  # type: ignore
-                        if isinstance(obj["type"], list):
+                        if "type" in obj and isinstance(obj["type"], list) and len(obj["type"]) > 1:
                             obj["type"] = obj["type"][0]
             if self.tool_choice is not None:
                 request_params["tool_choice"] = self.tool_choice
@@ -181,7 +181,7 @@ class Ollama(Model):
         request_kwargs = self.request_kwargs
         if self.response_format is not None and self.structured_outputs:
             if isinstance(self.response_format, type) and issubclass(self.response_format, BaseModel):
-                logger.debug("Using structured outputs")
+                log_debug("Using structured outputs")
                 format_schema = self.response_format.model_json_schema()
                 if "format" not in request_kwargs:
                     request_kwargs["format"] = format_schema
@@ -284,7 +284,7 @@ class Ollama(Model):
                 if parsed_object is not None:
                     model_response.parsed = parsed_object
         except Exception as e:
-            logger.warning(f"Error retrieving structured outputs: {e}")
+            log_warning(f"Error retrieving structured outputs: {e}")
 
         if response_message.get("role") is not None:
             model_response.role = response_message.get("role")
