@@ -1,3 +1,4 @@
+import time
 from dataclasses import dataclass
 from typing import Any, AsyncIterator, Dict, Iterator, List, Optional, Tuple, Union
 
@@ -5,41 +6,24 @@ import httpx
 from pydantic import BaseModel
 
 from agno.exceptions import ModelProviderError
+from agno.media import File
 from agno.models.base import MessageData, Model
-from agno.models.message import Message
+from agno.models.message import Citations, Message, UrlCitation
 from agno.models.response import ModelResponse
-from agno.utils.log import logger
+from agno.utils.log import log_error, log_warning
 from agno.utils.openai_responses import images_to_message
 
 try:
-    import importlib.metadata as metadata
-
     from openai import APIConnectionError, APIStatusError, AsyncOpenAI, OpenAI, RateLimitError
     from openai.resources.responses.responses import Response, ResponseStreamEvent
-    from packaging import version
-
-    # Get installed OpenAI version
-    openai_version = metadata.version("openai")
-
-    # Check version compatibility
-    parsed_version = version.parse(openai_version)
-    if parsed_version.major == 0 and parsed_version.minor < 66:
-        import warnings
-
-        warnings.warn("OpenAI v1.66.0 or higher is recommended for the Responses API", UserWarning)
-
-except ImportError as e:
-    # Handle different import error scenarios
-    if "openai" in str(e):
-        raise ImportError("OpenAI not installed. Install with `pip install openai -U`") from e
-    else:
-        raise ImportError("Missing dependencies. Install with `pip install packaging importlib-metadata`") from e
+except (ImportError, ModuleNotFoundError) as e:
+    raise ImportError("`openai` not installed. Please install using `pip install openai -U`") from e
 
 
 @dataclass
 class OpenAIResponses(Model):
     """
-    Implementation for the OpenAI Responses API using direct chat completions.
+    A class for interacting with OpenAI models using the Responses API.
 
     For more information, see: https://platform.openai.com/docs/api-reference/responses
     """
@@ -47,9 +31,23 @@ class OpenAIResponses(Model):
     id: str = "gpt-4o"
     name: str = "OpenAIResponses"
     provider: str = "OpenAI"
-    supports_structured_outputs: bool = True
+    supports_native_structured_outputs: bool = True
 
-    # API configuration
+    # Request parameters
+    include: Optional[List[str]] = None
+    max_output_tokens: Optional[int] = None
+    metadata: Optional[Dict[str, Any]] = None
+    parallel_tool_calls: Optional[bool] = None
+    reasoning: Optional[Dict[str, Any]] = None
+    store: Optional[bool] = None
+    temperature: Optional[float] = None
+    top_p: Optional[float] = None
+    truncation: Optional[str] = None
+    user: Optional[str] = None
+    response_format: Optional[Any] = None
+    request_params: Optional[Dict[str, Any]] = None
+
+    # Client parameters
     api_key: Optional[str] = None
     organization: Optional[str] = None
     base_url: Optional[Union[str, httpx.URL]] = None
@@ -60,25 +58,8 @@ class OpenAIResponses(Model):
     http_client: Optional[httpx.Client] = None
     client_params: Optional[Dict[str, Any]] = None
 
-    # Response parameters
-    temperature: Optional[float] = None
-    top_p: Optional[float] = None
-    max_output_tokens: Optional[int] = None
-    response_format: Optional[Dict[str, str]] = None
-    metadata: Optional[Dict[str, Any]] = None
-    store: Optional[bool] = None
-    reasoning_effort: Optional[str] = None
-
-    # Built-in tools
-    web_search: bool = False
-
-    # The role to map the message role to.
-    role_map = {
-        "system": "developer",
-        "user": "user",
-        "assistant": "assistant",
-        "tool": "tool",
-    }
+    # Parameters affecting built-in tools
+    vector_store_name: str = "knowledge_base"
 
     # OpenAI clients
     client: Optional[OpenAI] = None
@@ -88,6 +69,14 @@ class OpenAIResponses(Model):
     # Whether to use the structured outputs with this Model.
     structured_outputs: bool = False
 
+    # The role to map the message role to.
+    role_map = {
+        "system": "developer",
+        "user": "user",
+        "assistant": "assistant",
+        "tool": "tool",
+    }
+
     def _get_client_params(self) -> Dict[str, Any]:
         """
         Get client parameters for API requests.
@@ -101,7 +90,7 @@ class OpenAIResponses(Model):
         if not self.api_key:
             self.api_key = getenv("OPENAI_API_KEY")
             if not self.api_key:
-                logger.error("OPENAI_API_KEY not set. Please set the OPENAI_API_KEY environment variable.")
+                log_error("OPENAI_API_KEY not set. Please set the OPENAI_API_KEY environment variable.")
 
         # Define base client params
         base_params = {
@@ -162,8 +151,7 @@ class OpenAIResponses(Model):
         self.async_client = AsyncOpenAI(**client_params)
         return self.async_client
 
-    @property
-    def request_kwargs(self) -> Dict[str, Any]:
+    def get_request_params(self) -> Dict[str, Any]:
         """
         Returns keyword arguments for API requests.
 
@@ -171,20 +159,22 @@ class OpenAIResponses(Model):
             Dict[str, Any]: A dictionary of keyword arguments for API requests.
         """
         # Define base request parameters
-        base_params = {
-            "temperature": self.temperature,
-            "top_p": self.top_p,
+        base_params: Dict[str, Any] = {
+            "include": self.include,
             "max_output_tokens": self.max_output_tokens,
             "metadata": self.metadata,
+            "parallel_tool_calls": self.parallel_tool_calls,
+            "reasoning": self.reasoning,
             "store": self.store,
+            "temperature": self.temperature,
+            "top_p": self.top_p,
+            "truncation": self.truncation,
+            "user": self.user,
         }
-        if self.reasoning_effort is not None:
-            base_params["reasoning"] = {
-                "effort": self.reasoning_effort,
-            }
 
+        # Set the response format
         if self.response_format is not None:
-            if self.structured_outputs and isinstance(self.response_format, BaseModel):
+            if self.structured_outputs and issubclass(self.response_format, BaseModel):
                 schema = self.response_format.model_json_schema()
                 schema["additionalProperties"] = False
                 base_params["text"] = {
@@ -202,30 +192,111 @@ class OpenAIResponses(Model):
         # Filter out None values
         request_params: Dict[str, Any] = {k: v for k, v in base_params.items() if v is not None}
 
-        if self.web_search:
-            request_params.setdefault("tools", [])  # type: ignore
-            request_params["tools"].append({"type": "web_search_preview"})
-
-        # Add tools
-        if self._functions is not None and len(self._functions) > 0:
-            request_params.setdefault("tools", [])  # type: ignore
-            for function in self._functions.values():
-                function_dict = function.to_dict()
-                for prop in function_dict["parameters"]["properties"].values():
-                    if isinstance(prop["type"], list):
-                        prop["type"] = prop["type"][0]
-                request_params["tools"].append({"type": "function", **function_dict})
         if self.tool_choice is not None:
             request_params["tool_choice"] = self.tool_choice
 
+        # Add additional request params if provided
+        if self.request_params:
+            request_params.update(self.request_params)
         return request_params
 
+    def _upload_file(self, file: File) -> Optional[str]:
+        """Upload a file to the OpenAI vector database."""
+
+        if file.url is not None:
+            file_content_tuple = file.file_url_content
+            if file_content_tuple is not None:
+                file_content = file_content_tuple[0]
+            else:
+                return None
+            file_name = file.url.split("/")[-1]
+            file_tuple = (file_name, file_content)
+            result = self.get_client().files.create(file=file_tuple, purpose="assistants")
+            return result.id
+        elif file.filepath is not None:
+            import mimetypes
+            from pathlib import Path
+
+            file_path = file.filepath if isinstance(file.filepath, Path) else Path(file.filepath)
+            if file_path.exists() and file_path.is_file():
+                file_name = file_path.name
+                file_content = file_path.read_bytes()  # type: ignore
+                content_type = mimetypes.guess_type(file_path)[0]
+                result = self.get_client().files.create(
+                    file=(file_name, file_content, content_type),
+                    purpose="assistants",  # type: ignore
+                )
+                return result.id
+            else:
+                raise ValueError(f"File not found: {file_path}")
+        elif file.content is not None:
+            result = self.get_client().files.create(file=file.content, purpose="assistants")
+            return result.id
+
+        return None
+
+    def _create_vector_store(self, file_ids: List[str]) -> str:
+        """Create a vector store for the files."""
+        vector_store = self.get_client().vector_stores.create(name=self.vector_store_name)
+        for file_id in file_ids:
+            self.get_client().vector_stores.files.create(vector_store_id=vector_store.id, file_id=file_id)
+        while True:
+            uploaded_files = self.get_client().vector_stores.files.list(vector_store_id=vector_store.id)
+            all_completed = True
+            failed = False
+            for file in uploaded_files:
+                if file.status == "failed":
+                    log_error(f"File {file.id} failed to upload.")
+                    failed = True
+                    break
+                if file.status != "completed":
+                    all_completed = False
+            if all_completed or failed:
+                break
+            time.sleep(1)
+        return vector_store.id
+
+    def _format_tool_params(self, messages: List[Message]) -> List[Dict[str, Any]]:
+        """Format the tool parameters for the OpenAI Responses API."""
+        formatted_tools = []
+        if self._tools:
+            for _tool in self._tools:
+                if _tool["type"] == "function":
+                    _tool_dict = _tool["function"]
+                    _tool_dict["type"] = "function"
+                    for prop in _tool_dict["parameters"]["properties"].values():
+                        if isinstance(prop["type"], list):
+                            prop["type"] = prop["type"][0]
+
+                    formatted_tools.append(_tool_dict)
+                else:
+                    formatted_tools.append(_tool)
+
+        # Find files to upload to the OpenAI vector database
+        file_ids = []
+        for message in messages:
+            # Upload any attached files to the OpenAI vector database
+            if message.files is not None and len(message.files) > 0:
+                for file in message.files:
+                    file_id = self._upload_file(file)
+                    if file_id is not None:
+                        file_ids.append(file_id)
+
+        vector_store_id = self._create_vector_store(file_ids) if file_ids else None
+
+        # Add the file IDs to the tool parameters
+        for _tool in formatted_tools:
+            if _tool["type"] == "file_search" and vector_store_id is not None:
+                _tool["vector_store_ids"] = [vector_store_id]
+
+        return formatted_tools
+
     def _format_messages(self, messages: List[Message]) -> List[Dict[str, Any]]:
         """
         Format a message into the format expected by OpenAI.
 
         Args:
-            message (Message): The message to format.
+            messages (List[Message]): The message to format.
 
         Returns:
             Dict[str, Any]: The formatted message.
@@ -249,13 +320,11 @@ class OpenAIResponses(Model):
                         if message.images is not None:
                             message_dict["content"].extend(images_to_message(images=message.images))
 
-                # TODO: File support
-
                 if message.audio is not None:
-                    logger.warning("Audio input is currently unsupported.")
+                    log_warning("Audio input is currently unsupported.")
 
                 if message.videos is not None:
-                    logger.warning("Video input is currently unsupported.")
+                    log_warning("Video input is currently unsupported.")
 
                 formatted_messages.append(message_dict)
 
@@ -291,13 +360,17 @@ class OpenAIResponses(Model):
             Response: The response from the API.
         """
         try:
+            request_params = self.get_request_params()
+            if self._tools:
+                request_params["tools"] = self._format_tool_params(messages=messages)
+
             return self.get_client().responses.create(
                 model=self.id,
                 input=self._format_messages(messages),  # type: ignore
-                **self.request_kwargs,
+                **request_params,
             )
         except RateLimitError as e:
-            logger.error(f"Rate limit error from OpenAI API: {e}")
+            log_error(f"Rate limit error from OpenAI API: {e}")
             error_message = e.response.json().get("error", {})
             error_message = (
                 error_message.get("message", "Unknown model error")
@@ -311,10 +384,10 @@ class OpenAIResponses(Model):
                 model_id=self.id,
             ) from e
         except APIConnectionError as e:
-            logger.error(f"API connection error from OpenAI API: {e}")
+            log_error(f"API connection error from OpenAI API: {e}")
             raise ModelProviderError(message=str(e), model_name=self.name, model_id=self.id) from e
         except APIStatusError as e:
-            logger.error(f"API status error from OpenAI API: {e}")
+            log_error(f"API status error from OpenAI API: {e}")
             error_message = e.response.json().get("error", {})
             error_message = (
                 error_message.get("message", "Unknown model error")
@@ -328,7 +401,7 @@ class OpenAIResponses(Model):
                 model_id=self.id,
             ) from e
         except Exception as e:
-            logger.error(f"Error from OpenAI API: {e}")
+            log_error(f"Error from OpenAI API: {e}")
             raise ModelProviderError(message=str(e), model_name=self.name, model_id=self.id) from e
 
     async def ainvoke(self, messages: List[Message]) -> Response:
@@ -342,13 +415,16 @@ class OpenAIResponses(Model):
             Response: The response from the API.
         """
         try:
+            request_params = self.get_request_params()
+            if self._tools:
+                request_params["tools"] = self._format_tool_params(messages=messages)
             return await self.get_async_client().responses.create(
                 model=self.id,
                 input=self._format_messages(messages),  # type: ignore
-                **self.request_kwargs,
+                **request_params,
             )
         except RateLimitError as e:
-            logger.error(f"Rate limit error from OpenAI API: {e}")
+            log_error(f"Rate limit error from OpenAI API: {e}")
             error_message = e.response.json().get("error", {})
             error_message = (
                 error_message.get("message", "Unknown model error")
@@ -362,10 +438,10 @@ class OpenAIResponses(Model):
                 model_id=self.id,
             ) from e
         except APIConnectionError as e:
-            logger.error(f"API connection error from OpenAI API: {e}")
+            log_error(f"API connection error from OpenAI API: {e}")
             raise ModelProviderError(message=str(e), model_name=self.name, model_id=self.id) from e
         except APIStatusError as e:
-            logger.error(f"API status error from OpenAI API: {e}")
+            log_error(f"API status error from OpenAI API: {e}")
             error_message = e.response.json().get("error", {})
             error_message = (
                 error_message.get("message", "Unknown model error")
@@ -379,7 +455,7 @@ class OpenAIResponses(Model):
                 model_id=self.id,
             ) from e
         except Exception as e:
-            logger.error(f"Error from OpenAI API: {e}")
+            log_error(f"Error from OpenAI API: {e}")
             raise ModelProviderError(message=str(e), model_name=self.name, model_id=self.id) from e
 
     def invoke_stream(self, messages: List[Message]) -> Iterator[ResponseStreamEvent]:
@@ -393,14 +469,17 @@ class OpenAIResponses(Model):
             Iterator[ResponseStreamEvent]: An iterator of response stream events.
         """
         try:
+            request_params = self.get_request_params()
+            if self._tools:
+                request_params["tools"] = self._format_tool_params(messages=messages)
             yield from self.get_client().responses.create(
                 model=self.id,
                 input=self._format_messages(messages),  # type: ignore
                 stream=True,
-                **self.request_kwargs,
+                **request_params,
             )  # type: ignore
         except RateLimitError as e:
-            logger.error(f"Rate limit error from OpenAI API: {e}")
+            log_error(f"Rate limit error from OpenAI API: {e}")
             error_message = e.response.json().get("error", {})
             error_message = (
                 error_message.get("message", "Unknown model error")
@@ -414,10 +493,10 @@ class OpenAIResponses(Model):
                 model_id=self.id,
             ) from e
         except APIConnectionError as e:
-            logger.error(f"API connection error from OpenAI API: {e}")
+            log_error(f"API connection error from OpenAI API: {e}")
             raise ModelProviderError(message=str(e), model_name=self.name, model_id=self.id) from e
         except APIStatusError as e:
-            logger.error(f"API status error from OpenAI API: {e}")
+            log_error(f"API status error from OpenAI API: {e}")
             error_message = e.response.json().get("error", {})
             error_message = (
                 error_message.get("message", "Unknown model error")
@@ -431,7 +510,7 @@ class OpenAIResponses(Model):
                 model_id=self.id,
             ) from e
         except Exception as e:
-            logger.error(f"Error from OpenAI API: {e}")
+            log_error(f"Error from OpenAI API: {e}")
             raise ModelProviderError(message=str(e), model_name=self.name, model_id=self.id) from e
 
     async def ainvoke_stream(self, messages: List[Message]) -> AsyncIterator[ResponseStreamEvent]:
@@ -445,16 +524,19 @@ class OpenAIResponses(Model):
             Any: An asynchronous iterator of chat completion chunks.
         """
         try:
+            request_params = self.get_request_params()
+            if self._tools:
+                request_params["tools"] = self._format_tool_params(messages=messages)
             async_stream = await self.get_async_client().responses.create(
                 model=self.id,
                 input=self._format_messages(messages),  # type: ignore
                 stream=True,
-                **self.request_kwargs,
+                **request_params,
             )
             async for chunk in async_stream:  # type: ignore
                 yield chunk
         except RateLimitError as e:
-            logger.error(f"Rate limit error from OpenAI API: {e}")
+            log_error(f"Rate limit error from OpenAI API: {e}")
             error_message = e.response.json().get("error", {})
             error_message = (
                 error_message.get("message", "Unknown model error")
@@ -468,10 +550,10 @@ class OpenAIResponses(Model):
                 model_id=self.id,
             ) from e
         except APIConnectionError as e:
-            logger.error(f"API connection error from OpenAI API: {e}")
+            log_error(f"API connection error from OpenAI API: {e}")
             raise ModelProviderError(message=str(e), model_name=self.name, model_id=self.id) from e
         except APIStatusError as e:
-            logger.error(f"API status error from OpenAI API: {e}")
+            log_error(f"API status error from OpenAI API: {e}")
             error_message = e.response.json().get("error", {})
             error_message = (
                 error_message.get("message", "Unknown model error")
@@ -485,7 +567,7 @@ class OpenAIResponses(Model):
                 model_id=self.id,
             ) from e
         except Exception as e:
-            logger.error(f"Error from OpenAI API: {e}")
+            log_error(f"Error from OpenAI API: {e}")
             raise ModelProviderError(message=str(e), model_name=self.name, model_id=self.id) from e
 
     def format_function_call_results(
@@ -527,8 +609,20 @@ class OpenAIResponses(Model):
         model_response.role = "assistant"
         for output in response.output:
             if output.type == "message":
-                # TODO: Support citations/annotations
                 model_response.content = response.output_text
+
+                # Add citations
+                citations = Citations()
+                for content in output.content:
+                    if content.type == "output_text" and content.annotations:
+                        citations.raw = [annotation.model_dump() for annotation in content.annotations]
+                        for annotation in content.annotations:
+                            if annotation.type == "url_citation":
+                                if citations.urls is None:
+                                    citations.urls = []
+                                citations.urls.append(UrlCitation(url=annotation.url, title=annotation.title))
+                        if citations.urls or citations.documents:
+                            model_response.citations = citations
             elif output.type == "function_call":
                 if model_response.tool_calls is None:
                     model_response.tool_calls = []
@@ -548,7 +642,7 @@ class OpenAIResponses(Model):
                 model_response.extra.setdefault("tool_call_ids", []).append(output.call_id)
 
         # i.e. we asked for reasoning, so we need to add the reasoning content
-        if self.reasoning_effort:
+        if self.reasoning is not None:
             model_response.reasoning_content = response.output_text
 
         if response.usage is not None:
@@ -567,7 +661,7 @@ class OpenAIResponses(Model):
         Common handler for processing stream responses from Cohere.
 
         Args:
-            response: The streamed response from Cohere
+            stream_event: The streamed response from Cohere
             assistant_message: The assistant message being built
             stream_data: Data accumulated during streaming
             tool_use: Current tool use data being built
@@ -581,6 +675,21 @@ class OpenAIResponses(Model):
             # Update metrics
             if not assistant_message.metrics.time_to_first_token:
                 assistant_message.metrics.set_time_to_first_token()
+        elif stream_event.type == "response.output_text.annotation.added":
+            model_response = ModelResponse()
+            if stream_data.response_citations is None:
+                stream_data.response_citations = Citations(raw=[stream_event.annotation])
+            else:
+                stream_data.response_citations.raw.append(stream_event.annotation)  # type: ignore
+
+            if stream_event.annotation.type == "url_citation":
+                if stream_data.response_citations.urls is None:
+                    stream_data.response_citations.urls = []
+                stream_data.response_citations.urls.append(
+                    UrlCitation(url=stream_event.annotation.url, title=stream_event.annotation.title)
+                )
+
+            model_response.citations = stream_data.response_citations
 
         elif stream_event.type == "response.output_text.delta":
             model_response = ModelResponse()
@@ -588,7 +697,7 @@ class OpenAIResponses(Model):
             model_response.content = stream_event.delta
             stream_data.response_content += stream_event.delta
 
-            if self.reasoning_effort:
+            if self.reasoning is not None:
                 model_response.reasoning_content = stream_event.delta
                 stream_data.response_thinking += stream_event.delta
 
