@@ -4,6 +4,7 @@ from time import time
 from typing import Any, Dict, List, Optional
 
 from agno.media import AudioResponse
+from agno.models.message import Citations
 
 
 class ModelResponseEvent(str, Enum):
@@ -32,6 +33,8 @@ class ModelResponse:
     redacted_thinking: Optional[str] = None
     reasoning_content: Optional[str] = None
 
+    citations: Optional[Citations] = None
+
     response_usage: Optional[Any] = None
 
     created_at: int = int(time())
