@@ -20,6 +20,6 @@ class Together(OpenAILike):
 
     id: str = "mistralai/Mixtral-8x7B-Instruct-v0.1"
     name: str = "Together"
-    provider: str = "Together " + id
+    provider: str = "Together"
     api_key: Optional[str] = getenv("TOGETHER_API_KEY")
     base_url: str = "https://api.together.xyz/v1"
