@@ -4,8 +4,9 @@ from typing import Any, List, Literal, Optional
 from agno.storage.base import Storage
 from agno.storage.session import Session
 from agno.storage.session.agent import AgentSession
+from agno.storage.session.team import TeamSession
 from agno.storage.session.workflow import WorkflowSession
-from agno.utils.log import logger
+from agno.utils.log import log_debug, log_info, logger
 
 try:
     from sqlalchemy.dialects import mysql
@@ -29,7 +30,7 @@ class SingleStoreStorage(Storage):
         db_engine: Optional[Engine] = None,
         schema_version: int = 1,
         auto_upgrade_schema: bool = False,
-        mode: Optional[Literal["agent", "workflow"]] = "agent",
+        mode: Optional[Literal["agent", "team", "workflow"]] = "agent",
     ):
         """
         This class provides Agent storage using a singlestore table.
@@ -45,7 +46,7 @@ class SingleStoreStorage(Storage):
             db_engine (Optional[Engine], optional): The database engine. Defaults to None.
             schema_version (int, optional): The schema version. Defaults to 1.
             auto_upgrade_schema (bool, optional): Automatically upgrade the schema. Defaults to False.
-            mode (Optional[Literal["agent", "workflow"]], optional): The mode of the storage. Defaults to "agent".
+            mode (Optional[Literal["agent", "team", "workflow"]], optional): The mode of the storage. Defaults to "agent".
         """
         super().__init__(mode)
         _engine: Optional[Engine] = db_engine
@@ -73,12 +74,12 @@ class SingleStoreStorage(Storage):
         self.table: Table = self.get_table()
 
     @property
-    def mode(self) -> Literal["agent", "workflow"]:
+    def mode(self) -> Literal["agent", "team", "workflow"]:
         """Get the mode of the storage."""
         return super().mode
 
     @mode.setter
-    def mode(self, value: Optional[Literal["agent", "workflow"]]) -> None:
+    def mode(self, value: Optional[Literal["agent", "team", "workflow"]]) -> None:
         """Set the mode and refresh the table if mode changes."""
         super(SingleStoreStorage, type(self)).mode.fset(self, value)  # type: ignore
         if value is not None:
@@ -98,8 +99,15 @@ class SingleStoreStorage(Storage):
         if self.mode == "agent":
             specific_columns = [
                 Column("agent_id", mysql.TEXT),
+                Column("team_session_id", mysql.TEXT, nullable=True),
                 Column("agent_data", mysql.JSON),
             ]
+        elif self.mode == "team":
+            specific_columns = [
+                Column("team_id", mysql.TEXT),
+                Column("team_session_id", mysql.TEXT, nullable=True),
+                Column("team_data", mysql.JSON),
+            ]
         else:
             specific_columns = [
                 Column("workflow_id", mysql.TEXT),
@@ -108,7 +116,12 @@ class SingleStoreStorage(Storage):
 
         # Create table with all columns
         table = Table(
-            self.table_name, self.metadata, *common_columns, *specific_columns, extend_existing=True, schema=self.schema
+            self.table_name,
+            self.metadata,
+            *common_columns,
+            *specific_columns,
+            extend_existing=True,
+            schema=self.schema,  # type: ignore
         )
 
         return table
@@ -120,7 +133,7 @@ class SingleStoreStorage(Storage):
             raise ValueError(f"Unsupported schema version: {self.schema_version}")
 
     def table_exists(self) -> bool:
-        logger.debug(f"Checking if table exists: {self.table.name}")
+        log_debug(f"Checking if table exists: {self.table.name}")
         try:
             return inspect(self.db_engine).has_table(self.table.name, schema=self.schema)
         except Exception as e:
@@ -130,7 +143,7 @@ class SingleStoreStorage(Storage):
     def create(self) -> None:
         self.table = self.get_table()
         if not self.table_exists():
-            logger.info(f"\nCreating table: {self.table_name}\n")
+            log_info(f"\nCreating table: {self.table_name}\n")
             self.table.create(self.db_engine)
 
     def _read(self, session: SqlSession, session_id: str, user_id: Optional[str] = None) -> Optional[Row[Any]]:
@@ -140,9 +153,9 @@ class SingleStoreStorage(Storage):
         try:
             return session.execute(stmt).first()
         except Exception as e:
-            logger.debug(f"Exception reading from table: {e}")
-            logger.debug(f"Table does not exist: {self.table.name}")
-            logger.debug(f"Creating table: {self.table_name}")
+            log_debug(f"Exception reading from table: {e}")
+            log_debug(f"Table does not exist: {self.table.name}")
+            log_debug(f"Creating table: {self.table_name}")
             self.create()
         return None
 
@@ -152,6 +165,8 @@ class SingleStoreStorage(Storage):
             if existing_row is not None:
                 if self.mode == "agent":
                     return AgentSession.from_dict(existing_row._mapping)  # type: ignore
+                elif self.mode == "team":
+                    return TeamSession.from_dict(existing_row._mapping)  # type: ignore
                 else:
                     return WorkflowSession.from_dict(existing_row._mapping)  # type: ignore
             return None
@@ -167,6 +182,8 @@ class SingleStoreStorage(Storage):
                 if entity_id is not None:
                     if self.mode == "agent":
                         stmt = stmt.where(self.table.c.agent_id == entity_id)
+                    elif self.mode == "team":
+                        stmt = stmt.where(self.table.c.team_id == entity_id)
                     else:
                         stmt = stmt.where(self.table.c.workflow_id == entity_id)
                 # order by created_at desc
@@ -191,6 +208,8 @@ class SingleStoreStorage(Storage):
                 if entity_id is not None:
                     if self.mode == "agent":
                         stmt = stmt.where(self.table.c.agent_id == entity_id)
+                    elif self.mode == "team":
+                        stmt = stmt.where(self.table.c.team_id == entity_id)
                     else:
                         stmt = stmt.where(self.table.c.workflow_id == entity_id)
                 # order by created_at desc
@@ -203,18 +222,62 @@ class SingleStoreStorage(Storage):
                             _agent_session = AgentSession.from_dict(row._mapping)  # type: ignore
                             if _agent_session is not None:
                                 sessions.append(_agent_session)
+                        elif self.mode == "team":
+                            _team_session = TeamSession.from_dict(row._mapping)  # type: ignore
+                            if _team_session is not None:
+                                sessions.append(_team_session)
                         else:
                             _workflow_session = WorkflowSession.from_dict(row._mapping)  # type: ignore
                             if _workflow_session is not None:
                                 sessions.append(_workflow_session)
         except Exception:
-            logger.debug(f"Table does not exist: {self.table.name}")
+            log_debug(f"Table does not exist: {self.table.name}")
         return sessions
 
+    def upgrade_schema(self) -> None:
+        """
+        Upgrade the schema to the latest version.
+        Currently handles adding the team_session_id column for agent mode.
+        """
+        if not self.auto_upgrade_schema:
+            log_debug("Auto schema upgrade disabled. Skipping upgrade.")
+            return
+
+        try:
+            if self.mode == "agent" and self.table_exists():
+                with self.SqlSession() as sess:
+                    # Check if team_session_id column exists
+                    column_exists_query = text(
+                        """
+                        SELECT 1 FROM information_schema.columns
+                        WHERE table_schema = :schema AND table_name = :table
+                        AND column_name = 'team_session_id'
+                        """
+                    )
+                    column_exists = (
+                        sess.execute(column_exists_query, {"schema": self.schema, "table": self.table_name}).scalar()
+                        is not None
+                    )
+
+                    if not column_exists:
+                        log_info(f"Adding 'team_session_id' column to {self.schema}.{self.table_name}")
+                        alter_table_query = text(
+                            f"ALTER TABLE {self.schema}.{self.table_name} ADD COLUMN team_session_id TEXT"
+                        )
+                        sess.execute(alter_table_query)
+                        sess.commit()
+                        log_info("Schema upgrade completed successfully")
+        except Exception as e:
+            logger.error(f"Error during schema upgrade: {e}")
+            raise
+
     def upsert(self, session: Session) -> Optional[Session]:
         """
         Create a new session if it does not exist, otherwise update the existing session.
         """
+        # Perform schema upgrade if auto_upgrade_schema is enabled
+        if self.auto_upgrade_schema:
+            self.upgrade_schema()
 
         with self.SqlSession.begin() as sess:
             # Create an insert statement using MySQL's ON DUPLICATE KEY UPDATE syntax
@@ -222,11 +285,12 @@ class SingleStoreStorage(Storage):
                 upsert_sql = text(
                     f"""
                     INSERT INTO {self.schema}.{self.table_name}
-                    (session_id, agent_id, user_id, memory, agent_data, session_data, extra_data, created_at, updated_at)
+                    (session_id, agent_id, team_session_id, user_id, memory, agent_data, session_data, extra_data, created_at, updated_at)
                     VALUES
-                    (:session_id, :agent_id, :user_id, :memory, :agent_data, :session_data, :extra_data, UNIX_TIMESTAMP(), NULL)
+                    (:session_id, :agent_id, :team_session_id, :user_id, :memory, :agent_data, :session_data, :extra_data, UNIX_TIMESTAMP(), NULL)
                     ON DUPLICATE KEY UPDATE
                         agent_id = VALUES(agent_id),
+                        team_session_id = VALUES(team_session_id),
                         user_id = VALUES(user_id),
                         memory = VALUES(memory),
                         agent_data = VALUES(agent_data),
@@ -235,6 +299,24 @@ class SingleStoreStorage(Storage):
                         updated_at = UNIX_TIMESTAMP();
                     """
                 )
+            elif self.mode == "team":
+                upsert_sql = text(
+                    f"""
+                    INSERT INTO {self.schema}.{self.table_name}
+                    (session_id, team_id, user_id, team_session_id, memory, team_data, session_data, extra_data, created_at, updated_at)
+                    VALUES
+                    (:session_id, :team_id, :user_id, :team_session_id, :memory, :team_data, :session_data, :extra_data, UNIX_TIMESTAMP(), NULL)
+                    ON DUPLICATE KEY UPDATE
+                        team_id = VALUES(team_id),
+                        team_session_id = VALUES(team_session_id),
+                        user_id = VALUES(user_id),
+                        memory = VALUES(memory),
+                        team_data = VALUES(team_data),
+                        session_data = VALUES(session_data),
+                        extra_data = VALUES(extra_data),
+                        updated_at = UNIX_TIMESTAMP();
+                    """
+                )
             else:
                 upsert_sql = text(
                     f"""
@@ -260,6 +342,7 @@ class SingleStoreStorage(Storage):
                         {
                             "session_id": session.session_id,
                             "agent_id": session.agent_id,  # type: ignore
+                            "team_session_id": session.team_session_id,  # type: ignore
                             "user_id": session.user_id,
                             "memory": json.dumps(session.memory, ensure_ascii=False)
                             if session.memory is not None
@@ -275,6 +358,28 @@ class SingleStoreStorage(Storage):
                             else None,
                         },
                     )
+                elif self.mode == "team":
+                    sess.execute(
+                        upsert_sql,
+                        {
+                            "session_id": session.session_id,
+                            "team_id": session.team_id,  # type: ignore
+                            "user_id": session.user_id,
+                            "team_session_id": session.team_session_id,  # type: ignore
+                            "memory": json.dumps(session.memory, ensure_ascii=False)
+                            if session.memory is not None
+                            else None,
+                            "team_data": json.dumps(session.team_data, ensure_ascii=False)  # type: ignore
+                            if session.team_data is not None  # type: ignore
+                            else None,
+                            "session_data": json.dumps(session.session_data, ensure_ascii=False)
+                            if session.session_data is not None
+                            else None,
+                            "extra_data": json.dumps(session.extra_data, ensure_ascii=False)
+                            if session.extra_data is not None
+                            else None,
+                        },
+                    )
                 else:
                     sess.execute(
                         upsert_sql,
@@ -305,6 +410,7 @@ class SingleStoreStorage(Storage):
                         {
                             "session_id": session.session_id,
                             "agent_id": session.agent_id,  # type: ignore
+                            "team_session_id": session.team_session_id,  # type: ignore
                             "user_id": session.user_id,
                             "memory": json.dumps(session.memory, ensure_ascii=False)
                             if session.memory is not None
@@ -320,6 +426,28 @@ class SingleStoreStorage(Storage):
                             else None,
                         },
                     )
+                elif self.mode == "team":
+                    sess.execute(
+                        upsert_sql,
+                        {
+                            "session_id": session.session_id,
+                            "team_id": session.team_id,  # type: ignore
+                            "user_id": session.user_id,
+                            "team_session_id": session.team_session_id,  # type: ignore
+                            "memory": json.dumps(session.memory, ensure_ascii=False)
+                            if session.memory is not None
+                            else None,
+                            "team_data": json.dumps(session.team_data, ensure_ascii=False)  # type: ignore
+                            if session.team_data is not None  # type: ignore
+                            else None,
+                            "session_data": json.dumps(session.session_data, ensure_ascii=False)
+                            if session.session_data is not None
+                            else None,
+                            "extra_data": json.dumps(session.extra_data, ensure_ascii=False)
+                            if session.extra_data is not None
+                            else None,
+                        },
+                    )
                 else:
                     sess.execute(
                         upsert_sql,
@@ -357,19 +485,16 @@ class SingleStoreStorage(Storage):
                 if result.rowcount == 0:
                     logger.warning(f"No session found with session_id: {session_id}")
                 else:
-                    logger.info(f"Successfully deleted session with session_id: {session_id}")
+                    log_info(f"Successfully deleted session with session_id: {session_id}")
             except Exception as e:
                 logger.error(f"Error deleting session: {e}")
                 raise
 
     def drop(self) -> None:
         if self.table_exists():
-            logger.info(f"Deleting table: {self.table_name}")
+            log_info(f"Deleting table: {self.table_name}")
             self.table.drop(self.db_engine)
 
-    def upgrade_schema(self) -> None:
-        pass
-
     def __deepcopy__(self, memo):
         """
         Create a deep copy of the SingleStoreAgentStorage instance, handling unpickleable attributes.
