@@ -3,6 +3,7 @@ from os import getenv
 from typing import Any, Dict, List, Optional
 
 from agno.tools import Toolkit
+from agno.utils.functions import cache_result
 from agno.utils.log import logger
 
 try:
@@ -12,6 +13,20 @@ except ImportError:
 
 
 class FirecrawlTools(Toolkit):
+    """
+    Firecrawl is a tool for scraping and crawling websites.
+    Args:
+        api_key (Optional[str]): The API key to use for the Firecrawl app.
+        formats (Optional[List[str]]): The formats to use for the Firecrawl app.
+        limit (int): The maximum number of pages to crawl.
+        scrape (bool): Whether to scrape the website.
+        crawl (bool): Whether to crawl the website.
+        api_url (Optional[str]): The API URL to use for the Firecrawl app.
+        cache_results (bool): Whether to enable caching of search results.
+        cache_ttl (int): Time-to-live for cached results in seconds.
+        cache_dir (Optional[str]): Directory to store cache files.
+    """
+
     def __init__(
         self,
         api_key: Optional[str] = None,
@@ -20,6 +35,9 @@ class FirecrawlTools(Toolkit):
         scrape: bool = True,
         crawl: bool = False,
         api_url: Optional[str] = "https://api.firecrawl.dev",
+        cache_results: bool = False,
+        cache_ttl: int = 3600,
+        cache_dir: Optional[str] = None,
     ):
         super().__init__(name="firecrawl_tools")
 
@@ -42,6 +60,11 @@ class FirecrawlTools(Toolkit):
         if crawl:
             self.register(self.crawl_website)
 
+        self.cache_results = cache_results
+        self.cache_ttl = cache_ttl
+        self.cache_dir = cache_dir
+
+    @cache_result()
     def scrape_website(self, url: str) -> str:
         """Use this function to Scrapes a website using Firecrawl.
 
@@ -61,6 +84,7 @@ class FirecrawlTools(Toolkit):
         scrape_result = self.app.scrape_url(url, params=params)
         return json.dumps(scrape_result)
 
+    @cache_result()
     def crawl_website(self, url: str, limit: Optional[int] = None) -> str:
         """Use this function to Crawls a website using Firecrawl.
 
