@@ -2,7 +2,8 @@ import json
 from typing import Any, Dict, List, Optional
 
 from agno.tools import Toolkit
-from agno.utils.log import logger
+from agno.utils.functions import cache_result
+from agno.utils.log import log_debug
 
 try:
     from googlesearch import search
@@ -26,6 +27,9 @@ class GoogleSearchTools(Toolkit):
         headers (Optional[Any]): Custom headers for the request.
         proxy (Optional[str]): Proxy settings for the request.
         timeout (Optional[int]): Timeout for the request, default is 10 seconds.
+        cache_results (bool): Enable caching of search results.
+        cache_ttl (int): Time-to-live for cached results in seconds.
+        cache_dir (Optional[str]): Directory to store cache files.
     """
 
     def __init__(
@@ -35,6 +39,9 @@ class GoogleSearchTools(Toolkit):
         headers: Optional[Any] = None,
         proxy: Optional[str] = None,
         timeout: Optional[int] = 10,
+        cache_results: bool = False,
+        cache_ttl: int = 3600,
+        cache_dir: Optional[str] = None,
     ):
         super().__init__(name="googlesearch")
 
@@ -46,6 +53,11 @@ class GoogleSearchTools(Toolkit):
 
         self.register(self.google_search)
 
+        self.cache_results = cache_results
+        self.cache_ttl = cache_ttl
+        self.cache_dir = cache_dir
+
+    @cache_result()
     def google_search(self, query: str, max_results: int = 5, language: str = "en") -> str:
         """
         Use this function to search Google for a specified query.
@@ -69,7 +81,7 @@ class GoogleSearchTools(Toolkit):
             else:
                 language = "en"
 
-        logger.debug(f"Searching Google [{language}] for: {query}")
+        log_debug(f"Searching Google [{language}] for: {query}")
 
         # Perform Google search using the googlesearch-python package
         results = list(search(query, num_results=max_results, lang=language, proxy=self.proxy, advanced=True))
