@@ -8,7 +8,7 @@ from agno.agent import Agent
 from agno.media import AudioArtifact, ImageArtifact, VideoArtifact
 from agno.models.response import FileType
 from agno.tools import Toolkit
-from agno.utils.log import logger
+from agno.utils.log import log_debug, log_info, logger
 
 try:
     import requests
@@ -95,7 +95,7 @@ class ModelsLabTools(Toolkit):
     def _wait_for_media(self, media_id: str, eta: int) -> bool:
         """Wait for media generation to complete."""
         time_to_wait = min(eta + self.add_to_eta, self.max_wait_time)
-        logger.info(f"Waiting for {time_to_wait} seconds for {self.file_type.value} to be ready")
+        log_info(f"Waiting for {time_to_wait} seconds for {self.file_type.value} to be ready")
 
         for seconds_waited in range(time_to_wait):
             try:
@@ -125,7 +125,7 @@ class ModelsLabTools(Toolkit):
             payload = json.dumps(self._create_payload(prompt))
             headers = {"Content-Type": "application/json"}
 
-            logger.debug(f"Generating {self.file_type.value} for prompt: {prompt}")
+            log_debug(f"Generating {self.file_type.value} for prompt: {prompt}")
             response = requests.post(self.url, data=payload, headers=headers)
             response.raise_for_status()
 
@@ -150,7 +150,7 @@ class ModelsLabTools(Toolkit):
 
             if self.wait_for_completion and isinstance(eta, int):
                 if self._wait_for_media(media_id, eta):
-                    logger.info("Media generation completed successfully")
+                    log_info("Media generation completed successfully")
                 else:
                     logger.warning("Media generation timed out")
 
