@@ -1,5 +1,5 @@
 from agno.tools import Toolkit
-from agno.utils.log import logger
+from agno.utils.log import log_info, logger
 
 try:
     from openai import OpenAI as OpenAIClient
@@ -25,13 +25,13 @@ class OpenAITools(Toolkit):
         Returns:
             str: Transcribed text
         """
-        logger.info(f"Transcribing audio from {audio_path}")
+        log_info(f"Transcribing audio from {audio_path}")
         try:
             with open(audio_path, "rb") as audio_file:
                 transcript = client.audio.transcriptions.create(
                     model="whisper-1", file=audio_file, response_format="srt"
                 )
-                logger.info(f"Transcript: {transcript}")
+                log_info(f"Transcript: {transcript}")
             return transcript
         except Exception as e:
             logger.error(f"Failed to transcribe audio: {str(e)}")
