@@ -1,7 +1,7 @@
 import time
 
 from agno.tools import Toolkit
-from agno.utils.log import logger
+from agno.utils.log import log_info
 
 
 class SleepTools(Toolkit):
@@ -12,7 +12,7 @@ class SleepTools(Toolkit):
 
     def sleep(self, seconds: int) -> str:
         """Use this function to sleep for a given number of seconds."""
-        logger.info(f"Sleeping for {seconds} seconds")
+        log_info(f"Sleeping for {seconds} seconds")
         time.sleep(seconds)
-        logger.info(f"Awake after {seconds} seconds")
+        log_info(f"Awake after {seconds} seconds")
         return f"Slept for {seconds} seconds"
