@@ -4,7 +4,7 @@ from typing import Optional, Union
 import httpx
 
 from agno.tools import Toolkit
-from agno.utils.log import logger
+from agno.utils.log import log_debug, logger
 
 
 class TelegramTools(Toolkit):
@@ -30,7 +30,7 @@ class TelegramTools(Toolkit):
         :param message: The message to send.
         :return: The response from the API.
         """
-        logger.debug(f"Sending telegram message: {message}")
+        log_debug(f"Sending telegram message: {message}")
         response = self._call_post_method("sendMessage", json={"chat_id": self.chat_id, "text": message})
         try:
             response.raise_for_status()
