@@ -14,7 +14,7 @@ except ImportError:
 from agno.document import Document
 from agno.embedder import Embedder
 from agno.reranker.base import Reranker
-from agno.utils.log import logger
+from agno.utils.log import log_debug, log_info, logger
 from agno.vectordb.base import VectorDb
 from agno.vectordb.distance import Distance
 
@@ -38,7 +38,7 @@ class ChromaDb(VectorDb):
             from agno.embedder.openai import OpenAIEmbedder
 
             embedder = OpenAIEmbedder()
-            logger.info("Embedder not provided, using OpenAIEmbedder as default.")
+            log_info("Embedder not provided, using OpenAIEmbedder as default.")
         self.embedder: Embedder = embedder
         # Distance metric
         self.distance: Distance = distance
@@ -63,12 +63,12 @@ class ChromaDb(VectorDb):
     def client(self) -> ClientAPI:
         if self._client is None:
             if not self.persistent_client:
-                logger.debug("Creating Chroma Client")
+                log_debug("Creating Chroma Client")
                 self._client = ChromaDbClient(
                     **self.kwargs,
                 )
             elif self.persistent_client:
-                logger.debug("Creating Persistent Chroma Client")
+                log_debug("Creating Persistent Chroma Client")
                 self._client = PersistentChromaDbClient(
                     path=self.path,
                     **self.kwargs,
@@ -78,10 +78,10 @@ class ChromaDb(VectorDb):
     def create(self) -> None:
         """Create the collection in ChromaDb."""
         if self.exists():
-            logger.debug(f"Collection already exists: {self.collection_name}")
+            log_debug(f"Collection already exists: {self.collection_name}")
             self._collection = self.client.get_collection(name=self.collection_name)
         else:
-            logger.debug(f"Creating collection: {self.collection_name}")
+            log_debug(f"Creating collection: {self.collection_name}")
             self._collection = self.client.create_collection(
                 name=self.collection_name, metadata={"hnsw:space": self.distance.value}
             )
@@ -131,7 +131,7 @@ class ChromaDb(VectorDb):
             documents (List[Document]): List of documents to insert
             filters (Optional[Dict[str, Any]]): Filters to apply while inserting documents
         """
-        logger.debug(f"Inserting {len(documents)} documents")
+        log_debug(f"Inserting {len(documents)} documents")
         ids: List = []
         docs: List = []
         docs_embeddings: List = []
@@ -148,14 +148,14 @@ class ChromaDb(VectorDb):
             docs.append(cleaned_content)
             ids.append(doc_id)
             docs_metadata.append(document.meta_data)
-            logger.debug(f"Inserted document: {document.id} | {document.name} | {document.meta_data}")
+            log_debug(f"Inserted document: {document.id} | {document.name} | {document.meta_data}")
 
         if self._collection is None:
             logger.warning("Collection does not exist")
         else:
             if len(docs) > 0:
                 self._collection.add(ids=ids, embeddings=docs_embeddings, documents=docs, metadatas=docs_metadata)
-                logger.debug(f"Committed {len(docs)} documents")
+                log_debug(f"Committed {len(docs)} documents")
 
     def upsert_available(self) -> bool:
         """Check if upsert is available in ChromaDB."""
@@ -168,7 +168,7 @@ class ChromaDb(VectorDb):
             documents (List[Document]): List of documents to upsert
             filters (Optional[Dict[str, Any]]): Filters to apply while upserting
         """
-        logger.debug(f"Upserting {len(documents)} documents")
+        log_debug(f"Upserting {len(documents)} documents")
         ids: List = []
         docs: List = []
         docs_embeddings: List = []
@@ -185,14 +185,14 @@ class ChromaDb(VectorDb):
             docs.append(cleaned_content)
             ids.append(doc_id)
             docs_metadata.append(document.meta_data)
-            logger.debug(f"Upserted document: {document.id} | {document.name} | {document.meta_data}")
+            log_debug(f"Upserted document: {document.id} | {document.name} | {document.meta_data}")
 
         if self._collection is None:
             logger.warning("Collection does not exist")
         else:
             if len(docs) > 0:
                 self._collection.upsert(ids=ids, embeddings=docs_embeddings, documents=docs, metadatas=docs_metadata)
-                logger.debug(f"Committed {len(docs)} documents")
+                log_debug(f"Committed {len(docs)} documents")
 
     def search(self, query: str, limit: int = 5, filters: Optional[Dict[str, Any]] = None) -> List[Document]:
         """Search the collection for a query.
@@ -253,7 +253,7 @@ class ChromaDb(VectorDb):
     def drop(self) -> None:
         """Delete the collection."""
         if self.exists():
-            logger.debug(f"Deleting collection: {self.collection_name}")
+            log_debug(f"Deleting collection: {self.collection_name}")
             self.client.delete_collection(name=self.collection_name)
 
     def exists(self) -> bool:
@@ -262,7 +262,7 @@ class ChromaDb(VectorDb):
             self.client.get_collection(name=self.collection_name)
             return True
         except Exception as e:
-            logger.debug(f"Collection does not exist: {e}")
+            log_debug(f"Collection does not exist: {e}")
         return False
 
     def get_count(self) -> int:
