@@ -1,3 +1,3 @@
-from agno.vectordb.clickhouse.clickhousedb import ClickhouseDb
+from agno.vectordb.clickhouse.clickhousedb import Clickhouse
 from agno.vectordb.clickhouse.index import HNSW
 from agno.vectordb.distance import Distance
