@@ -11,7 +11,7 @@ except ImportError:
 
 from agno.document import Document
 from agno.embedder import Embedder
-from agno.utils.log import logger
+from agno.utils.log import log_debug, log_info, logger
 from agno.vectordb.base import VectorDb
 from agno.vectordb.distance import Distance
 
@@ -54,7 +54,7 @@ class Clickhouse(VectorDb):
             from agno.embedder.openai import OpenAIEmbedder
 
             _embedder = OpenAIEmbedder()
-            logger.info("Embedder not provided, using OpenAIEmbedder as default.")
+            log_info("Embedder not provided, using OpenAIEmbedder as default.")
         self.embedder: Embedder = _embedder
         self.dimensions: Optional[int] = self.embedder.dimensions
 
@@ -71,7 +71,7 @@ class Clickhouse(VectorDb):
         }
 
     def table_exists(self) -> bool:
-        logger.debug(f"Checking if table exists: {self.table_name}")
+        log_debug(f"Checking if table exists: {self.table_name}")
         try:
             parameters = self._get_base_parameters()
             return bool(
@@ -86,14 +86,14 @@ class Clickhouse(VectorDb):
 
     def create(self) -> None:
         if not self.table_exists():
-            logger.debug(f"Creating Database: {self.database_name}")
+            log_debug(f"Creating Database: {self.database_name}")
             parameters = {"database_name": self.database_name}
             self.client.command(
                 "CREATE DATABASE IF NOT EXISTS {database_name:Identifier}",
                 parameters=parameters,
             )
 
-            logger.debug(f"Creating table: {self.table_name}")
+            log_debug(f"Creating table: {self.table_name}")
 
             parameters = self._get_base_parameters()
 
@@ -213,7 +213,7 @@ class Clickhouse(VectorDb):
                 "content_hash",
             ],
         )
-        logger.debug(f"Inserted {len(documents)} documents")
+        log_debug(f"Inserted {len(documents)} documents")
 
     def upsert_available(self) -> bool:
         return True
@@ -270,8 +270,8 @@ class Clickhouse(VectorDb):
             "{database_name:Identifier}.{table_name:Identifier} "
             f"{where_query} {order_by_query} LIMIT {limit}"
         )
-        logger.debug(f"Query: {clickhouse_query}")
-        logger.debug(f"Params: {parameters}")
+        log_debug(f"Query: {clickhouse_query}")
+        log_debug(f"Params: {parameters}")
 
         try:
             results = self.client.query(
@@ -302,7 +302,7 @@ class Clickhouse(VectorDb):
 
     def drop(self) -> None:
         if self.table_exists():
-            logger.debug(f"Deleting table: {self.table_name}")
+            log_debug(f"Deleting table: {self.table_name}")
             parameters = self._get_base_parameters()
             self.client.command(
                 "DROP TABLE {database_name:Identifier}.{table_name:Identifier}",
@@ -324,7 +324,7 @@ class Clickhouse(VectorDb):
         return 0
 
     def optimize(self) -> None:
-        logger.debug("==== No need to optimize Clickhouse DB. Skipping this step ====")
+        log_debug("==== No need to optimize Clickhouse DB. Skipping this step ====")
 
     def delete(self) -> bool:
         parameters = self._get_base_parameters()
